@@ -3,7 +3,9 @@
 ALL_EPLUS_VER <- c(
     paste0("7.", 0:2, ".0"),
     paste0("8.", 0:9, ".0"), paste0("8.3.", 1:3),
-    paste0("9.0.", 0:1), paste0("9.", 1:6, ".0")
+    paste0("9.0.", 0:1), paste0("9.", 1:6, ".0"),
+    paste0("22.", 1:2, ".0"),
+    paste0("23.", 1, ".0")
 )
 
 LATEST_EPLUS_VER <- ALL_EPLUS_VER[length(ALL_EPLUS_VER)]
@@ -19,11 +21,16 @@ ALL_IDD_VER <- c(
     paste0("7.", 0:2, ".0"),
     paste0("8.", 0:9, ".0"),
     paste0("9.0.", 0:1),
-    paste0("9.", 1:6, ".0")
+    paste0("9.", 1:6, ".0"),
+    paste0("22.", 1:2, ".0"),
+    paste0("23.", 1, ".0")
 )
 
 ALL_EPLUS_RELEASE_COMMIT <- data.table::fread(
     "version , commit
+     23.1.0  , 87ed9199d4
+     22.2.0  , c249759bad
+     22.1.0  , ed759b17ee
      9.6.0   , f420c06a69
      9.5.0   , de239b2e5f
      9.4.0   , 998c4b761e
@@ -140,7 +147,9 @@ utils::globalVariables(c(
     "area", "dt", "interval_type", "new_rleid", "time_index", "i.time_index",
     "i.environment_name", "i.environment_type", "i.simulation_index", "i.new",
     "value_lower_start", "expand_obj", "i.year", "provider", "energyplus_exe",
-    "exist", "resources", "ver", "Name", "param_index"
+    "exist", "resources", "ver", "Name", "param_index", "i.space_name"
 ))
 # }}}
 # nocov end
+
+# vim: set fdm=marker:
